GeminiClient

Struct GeminiClient 

pub struct GeminiClient { /* private fields */ }
Client for Google Gemini API

Implementations

Source

impl GeminiClient

pub fn new(api_key: String) -> GeminiClient

Create a new Gemini client with the given API key

pub fn new_with_base_url(api_key: String, base_url: String) -> GeminiClient

Create a new Gemini client with an explicit base URL

pub fn with_base_url(self, url: String) -> GeminiClient

Set custom base URL

pub fn with_authorizer( self, authorizer: Arc<dyn HttpAuthorizer>, ) -> GeminiClient

Attach a dynamic authorizer (Code Assist / Vertex ADC Bearer token path). When set, x-goog-api-key is NOT sent; the authorizer injects its own headers (typically Authorization: Bearer <token>).

pub fn with_code_assist_wire(self) -> GeminiClient

pub fn with_code_assist_project_id( self, project_id: Option<String>, ) -> GeminiClient