ToolCallBuffer

Struct ToolCallBuffer 

pub struct ToolCallBuffer {
    pub id: String,
    pub name: Option<String>,
    pub args_json: String,
}
Buffer for accumulating tool call arguments during streaming

Uses pre-allocated capacity to minimize allocations during streaming. The default capacity of 256 bytes handles most small tool arguments without reallocation.

Fields

id: Stringname: Option<String>args_json: String

Implementations

Source

impl ToolCallBuffer

pub fn new(id: String) -> Self

Create a new buffer for a tool call with pre-allocated capacity

pub fn with_capacity(id: String, capacity: usize) -> Self

Create a new buffer with custom capacity for large arguments

pub fn push_args(&mut self, delta: &str)

Append to the args buffer

pub fn try_complete(&self) -> Option<ToolCall>

Try to complete the tool call (parse JSON args)